<?php

namespace Civi\Api4;

/**
 * Phone entity.
 *
 * This entity allows user to add, update, retrieve or delete phone number(s) of a contact.
 *
 * Creating a new phone of a contact, requires at minimum a contact's ID and phone number
 *
 * @package Civi\Api4
 */
class Phone extends Generic\DAOEntity {

}
